==> lb_plus-3.1.0.tar.gz: lb_plus/js/lb-plus-tool-plugin.js <==
import * as toolPluginBase from '../../toolbar_plus/js/toolbar_plus/tool-plugin-base.js';

export const messageNoLayout = (e, type) => {
  const messages = new Drupal.Message();
  const messageId = messages.add('No layout loaded.', {type: 'error'})
  setTimeout(() => {
    messages.remove(messageId);
  }, 2000);
}

(($, Drupal, once, displace) => {

  Drupal.LBPlusUi = {};

  /**
   * Toolbar+ plugin
   */
  class LbPlusPlugin extends toolPluginBase.ToolPluginBase {
    id = 'lb_plus';
    enable = () => {
      super.enable();
      return new Promise((resolve, reject) =>  {
        Drupal.LBPlusUi.getLayoutBuilder(resolve, reject);
      });
    }
    disable = (editModeDisabled = false) => {
      const ignoredPromise = super.disable();
      Drupal.behaviors.LBPlusToggleSidebar.closeSideBar();
      if (editModeDisabled) {
        // Let toolbar+ get the rendered page.
        return Promise.resolve();
      } else {
        return new Promise((resolve, reject) => {
          Drupal.LBPlusUi.getRenderedPage(resolve, reject);
        });
      }
    }
    initialEdit() {
      if (document.querySelector('#lb_plus-left-sidebar').classList.contains('toolbar-plus-hidden')) {
        document.querySelector('#lb-plus-toggle-sidebar').click();
      }
    }
  }
  Drupal.ToolbarPlus.PluginManager.registerPlugin(new LbPlusPlugin());

  /**
   * Get rendered page.
   *
   * Disable layout builder mode callback.
   *
   * @param resolve
   * @param reject
   */
  Drupal.LBPlusUi.getRenderedPage = (resolve, reject) => {
    const layoutBuilderElement = document.querySelector('#layout-builder');
    if (!layoutBuilderElement) {
      resolve();
      return;
    }
    const wrapper = layoutBuilderElement.closest('.toolbar-plus-entity-wrapper');
    const parts = wrapper.dataset.toolbarPlusEntityWrapper.split('::');

    let ajax = toolPluginBase.ajax({
      url: Drupal.url('lb-plus/disable-layout-mode/overrides/' + parts[0] + '.' + parts[1] + '/' + wrapper.dataset.toolbarPlusViewMode),
      type: 'POST',
      dataType: 'text',
      progress: {
        type: 'fullscreen',
        message: Drupal.t('Loading Layout Builder...')
      },
      error: error => {
        console.error(error.responseText);
        reject(error);
      },
      success: (response, status) => {
        Promise.resolve(
          Drupal.Ajax.prototype.success.call(ajax, response, status)
        ).then(() => {
          resolve();
        }).catch((e) => {
          reject(e.responseText);
        });
      }
    });
    ajax.execute();
  }

  /**
   * Get layout builder.
   *
   * Enable layout builder mode callback.
   */
  Drupal.LBPlusUi.getLayoutBuilder = (resolve, reject) => {
    const wrapper = document.querySelector('.toolbar-plus-entity-wrapper.layout-builder-entity-wrapper');
    if (!wrapper) {
      return;
    }
    const parts = wrapper.dataset.toolbarPlusEntityWrapper.split('::');

    let ajax = toolPluginBase.ajax({
      url: Drupal.url('lb-plus/enable-layout-mode/overrides/' + parts[0] + '.' + parts[1]),
      type: 'POST',
      dataType: 'text',
      progress: {
        type: 'fullscreen',
        message: Drupal.t('Loading Layout Builder...')
      },
      error: error => {
        document.querySelectorAll('.ajax-progress').forEach(progress => {
          progress.remove();
        });
        messageNoLayout();
        console.info('Attempted to load layout builder UI for ' + wrapper.dataset.toolbarPlusEntityWrapper);
        console.info(error.responseText);
      },
      success: (response, status) => {
        Promise.resolve(
          Drupal.Ajax.prototype.success.call(ajax, response, status)
        ).then(() => {
          displace(true);
          resolve();
        }).catch((e) => {
          reject(e.responseText);
        });
      }
    });
    ajax.execute();
  }

  Drupal.behaviors.LBPlusToggleSidebar = {
    attach: (context, settings) => {

      // Toggle the sidebar on and off when clicked.
      once('LBPlusToggleSidebar', '#lb-plus-toggle-sidebar', context).forEach(toggleButton => {
        toggleButton.onclick = e => {
          const sideBar = Drupal.behaviors.LBPlusToggleSidebar.getSideBar()
          if (sideBar.classList.contains('toolbar-plus-hidden')) {
            Drupal.behaviors.LBPlusToggleSidebar.openSideBar();
          } else {
            Drupal.behaviors.LBPlusToggleSidebar.closeSideBar();
          }
        };
      });

      // Close sidebar button.
      once('LBPlusCloseSidebar', '#close-add-block-sidebar', context).forEach(closeButton => {
        closeButton.onclick = e => {
          Drupal.behaviors.LBPlusToggleSidebar.closeSideBar();
        };
      });

      // Blank page sidebar button.
      once('LBPlusBlankPageOpenSidebar', '.blank-page-wrapper', context).forEach(blankPageButton => {
        blankPageButton.onclick = e => {
          Drupal.behaviors.LBPlusToggleSidebar.openSideBar();
        };
      });

      // Close the sidebar when an offcanvas dialog opens.
      $(window).on('dialog:aftercreate', (event, dialog, $element) => {
        if ($element.length && $element[0].id === 'drupal-off-canvas') {
          Drupal.behaviors.LBPlusToggleSidebar.closeSideBar();
        }
      });
    },
    openSideBar: () => {
      // Open the sidebar, remember the state, and set the toggle button rotation.
      const sidebar = Drupal.behaviors.LBPlusToggleSidebar.getSideBar();

      if (sidebar.querySelector('#lb-plus-sidebar-placeholder')) {
        messageNoLayout();
        return;
      }

      sidebar.classList.remove('toolbar-plus-hidden');
      sidebar.setAttribute('data-offset-left', '');
      displace();
      document.cookie="lbPlusSidebar=open; path=/";
      document.getElementById('lb-plus-toggle-sidebar').classList.add('active');
    },
    closeSideBar: () => {
      // Close the sidebar, remember the state, and set the toggle button rotation.
      const sidebar = Drupal.behaviors.LBPlusToggleSidebar.getSideBar();
      sidebar.classList.add('toolbar-plus-hidden');
      sidebar.removeAttribute('data-offset-left');
      displace();
      document.cookie="lbPlusSidebar=closed; path=/";
      document.getElementById('lb-plus-toggle-sidebar').classList.remove('active');
    },
    getSideBar: () => {
      return document.getElementById('lb_plus-left-sidebar');
    },
  };


  /**
   * Choose block tabs.
   *
   * @type {{attach: Drupal.behaviors.LBPlusChooseBlockTabs.attach}}
   */
  Drupal.behaviors.LBPlusChooseBlockTabs = {
    attach: (context, settings) => {
      once('LBPlusChooseBlockTabs', '.choose-block-tab', context).forEach(tab => {
        tab.onclick = (e) => {
          // Make no tab active.
          let noLongerActiveElements = [
            ...document.querySelectorAll('.tabbed-content'),
            ...document.querySelectorAll('.choose-block-tab'),
          ];
          noLongerActiveElements.forEach(tabbedContent => {
            tabbedContent.classList.remove('active');
          });
          // Activate the selected tab.
          e.target.classList.add('active')
          document.getElementById(e.target.id + '-content').classList.add('active');
        };
      });
    }
  };

  let layoutBuilderBlocksFiltered = false;

  /**
   * Provides the ability to filter the block listing in "Add block" dialog.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attach block filtering behavior to "Add block" dialog.
   */
  Drupal.behaviors.LBPlusBlockFilter = {
    attach(context) {
      const $categories = $('.js-layout-builder-categories', context);
      const $filterLinks = $categories.find('.js-layout-builder-block-link');

      /**
       * Filters the block list.
       *
       * @param {jQuery.Event} e
       *   The jQuery event for the keyup event that triggered the filter.
       */
      const filterBlockList = (e) => {
        const query = e.target.value.toLowerCase();

        /**
         * Shows or hides the block entry based on the query.
         *
         * @param {number} index
         *   The index in the loop, as provided by `jQuery.each`
         * @param {HTMLElement} link
         *   The link to add the block.
         */
        const toggleBlockEntry = (index, link) => {
          const $link = $(link);
          const textMatch =
            link.textContent.toLowerCase().indexOf(query) !== -1;
          // Checks if a category is currently hidden.
          // Toggles the category on if so.
          if ($link.closest('.js-layout-builder-category').is(':hidden')) {
            $link.closest('.js-layout-builder-category').show();
          }
          // Toggle the li tag of the matching link.
          // $link.parent().toggle(textMatch);
          $link.toggle(textMatch);
        };

        // Filter if the length of the query is at least 2 characters.
        if (query.length >= 2) {
          // Attribute to note which categories are closed before opening all.
          $categories
            .find('.js-layout-builder-category:not([open])')
            .attr('remember-closed', '');

          // Open all categories so every block is available to filtering.
          $categories.find('.js-layout-builder-category').attr('open', '');
          // Toggle visibility of links based on query.
          $filterLinks.each(toggleBlockEntry);

          // Only display categories containing visible links.
          $categories
            .find(
              '.js-layout-builder-category:not(:has(.js-layout-builder-block-link:visible))',
            )
            .hide();

          Drupal.announce(
            Drupal.formatPlural(
              $categories.find('.js-layout-builder-block-link:visible').length,
              '1 block is available in the modified list.',
              '@count blocks are available in the modified list.',
            ),
          );
          layoutBuilderBlocksFiltered = true;
        } else if (layoutBuilderBlocksFiltered) {
          layoutBuilderBlocksFiltered = false;
          // Remove "open" attr from categories that were closed pre-filtering.
          $categories
            .find('.js-layout-builder-category[remember-closed]')
            .removeAttr('open')
            .removeAttr('remember-closed');
          // Show all categories since filter is turned off.
          $categories.find('.js-layout-builder-category').show();
          // Show all blocks since filter is turned off.
          $filterLinks.show();
          Drupal.announce(Drupal.t('All available blocks are listed.'));
        }
      };

      $(
        once('block-filter-text', 'input.js-layout-builder-filter', context),
      ).on('input', Drupal.debounce(filterBlockList, 200));
    },
  };
})(jQuery, Drupal, once, Drupal.displace);

==> lb_plus-3.1.1.tar.gz: lb_plus/js/lb-plus-tool-plugin.js <==

export const messageNoLayout = (e, type) => {
  const messages = new Drupal.Message();
  const messageId = messages.add('No layout loaded.', {type: 'error'})
  setTimeout(() => {
    messages.remove(messageId);
  }, 2000);
}

(($, Drupal, once, displace) => {

  Drupal.LBPlusUi = {};

  /**
   * Navigation + plugin
   */
  class LbPlusToolPlugin extends Drupal.NavigationPlus.ToolPluginBase {
    id = 'lb_plus';
    enable = () => {
      super.enable();
      return new Promise((resolve, reject) =>  {
        Drupal.LBPlusUi.getLayoutBuilder(resolve, reject);
      });
    }
    disable = (editModeDisabled = false) => {
      const ignoredPromise = super.disable();
      Drupal.behaviors.LBPlusToggleSidebar.closeSideBar();
      if (editModeDisabled) {
        // Let toolbar+ get the rendered page.
        return Promise.resolve();
      } else {
        return new Promise((resolve, reject) => {
          Drupal.LBPlusUi.getRenderedPage(resolve, reject);
        });
      }
    }
    initialEdit() {
      if (document.querySelector('#lb_plus-left-sidebar').classList.contains('navigation-plus-hidden')) {
        document.querySelector('#lb-plus-toggle-sidebar').click();
      }
    }
  }
  Drupal.NavigationPlus.ToolManager.registerPlugin(new LbPlusToolPlugin());

  /**
   * Get rendered page.
   *
   * Disable layout builder mode callback.
   *
   * @param resolve
   * @param reject
   */
  Drupal.LBPlusUi.getRenderedPage = (resolve, reject) => {
    const layoutBuilderElement = document.querySelector('#layout-builder');
    if (!layoutBuilderElement) {
      resolve();
      return;
    }
    const wrapper = layoutBuilderElement.closest('.navigation-plus-entity-wrapper');
    const parts = wrapper.dataset.navigationPlusEntityWrapper.split('::');

    let ajax = Drupal.NavigationPlus.ModePluginBase.ajax({
      url: Drupal.url('lb-plus/disable-layout-mode/overrides/' + parts[0] + '.' + parts[1] + '/' + wrapper.dataset.navigationPlusViewMode),
      type: 'POST',
      dataType: 'text',
      progress: {
        type: 'fullscreen',
        message: Drupal.t('Loading Layout Builder...')
      },
      error: error => {
        console.error(error.responseText);
        reject(error);
      },
      success: (response, status) => {
        Promise.resolve(
          Drupal.Ajax.prototype.success.call(ajax, response, status)
        ).then(() => {
          resolve();
        }).catch((e) => {
          reject(e.responseText);
        });
      }
    });
    ajax.execute();
  }

  /**
   * Get layout builder.
   *
   * Enable layout builder mode callback.
   */
  Drupal.LBPlusUi.getLayoutBuilder = (resolve, reject) => {
    const wrapper = document.querySelector('.navigation-plus-entity-wrapper.layout-builder-entity-wrapper');
    if (!wrapper) {
      return;
    }
    const parts = wrapper.dataset.navigationPlusEntityWrapper.split('::');

    let ajax = Drupal.NavigationPlus.ModePluginBase.ajax({
      url: Drupal.url('lb-plus/enable-layout-mode/overrides/' + parts[0] + '.' + parts[1]),
      type: 'POST',
      dataType: 'text',
      progress: {
        type: 'fullscreen',
        message: Drupal.t('Loading Layout Builder...')
      },
      error: error => {
        document.querySelectorAll('.ajax-progress').forEach(progress => {
          progress.remove();
        });
        messageNoLayout();
        console.info('Attempted to load layout builder UI for ' + wrapper.dataset.navigationPlusEntityWrapper);
        console.info(error.responseText);
      },
      success: (response, status) => {
        Promise.resolve(
          Drupal.Ajax.prototype.success.call(ajax, response, status)
        ).then(() => {
          displace(true);
          resolve();
        }).catch((e) => {
          reject(e.responseText);
        });
      }
    });
    ajax.execute();
  }

  Drupal.behaviors.LBPlusToggleSidebar = {
    attach: (context, settings) => {

      // Toggle the sidebar on and off when clicked.
      once('LBPlusToggleSidebar', '#lb-plus-toggle-sidebar', context).forEach(toggleButton => {
        toggleButton.onclick = e => {
          const sideBar = Drupal.behaviors.LBPlusToggleSidebar.getSideBar()
          if (sideBar.classList.contains('navigation-plus-hidden')) {
            Drupal.behaviors.LBPlusToggleSidebar.openSideBar();
          } else {
            Drupal.behaviors.LBPlusToggleSidebar.closeSideBar();
          }
        };
      });

      // Close sidebar button.
      once('LBPlusCloseSidebar', '#close-add-block-sidebar', context).forEach(closeButton => {
        closeButton.onclick = e => {
          Drupal.behaviors.LBPlusToggleSidebar.closeSideBar();
        };
      });

      // Blank page sidebar button.
      once('LBPlusBlankPageOpenSidebar', '.blank-page-wrapper', context).forEach(blankPageButton => {
        blankPageButton.onclick = e => {
          Drupal.behaviors.LBPlusToggleSidebar.openSideBar();
        };
      });

      // Close the sidebar when an offcanvas dialog opens.
      $(window).on('dialog:aftercreate', (event, dialog, $element) => {
        if ($element.length && $element[0].id === 'drupal-off-canvas') {
          Drupal.behaviors.LBPlusToggleSidebar.closeSideBar();
        }
      });
    },
    openSideBar: () => {
      // Open the sidebar, remember the state, and set the toggle button rotation.
      const sidebar = Drupal.behaviors.LBPlusToggleSidebar.getSideBar();

      if (sidebar.querySelector('#lb-plus-sidebar-placeholder')) {
        messageNoLayout();
        return;
      }

      sidebar.classList.remove('navigation-plus-hidden');
      sidebar.setAttribute('data-offset-left', '');
      displace();
      document.cookie="lbPlusSidebar=open; path=/";
      document.getElementById('lb-plus-toggle-sidebar').classList.add('active');
    },
    closeSideBar: () => {
      // Close the sidebar, remember the state, and set the toggle button rotation.
      const sidebar = Drupal.behaviors.LBPlusToggleSidebar.getSideBar();
      sidebar.classList.add('navigation-plus-hidden');
      sidebar.removeAttribute('data-offset-left');
      displace();
      document.cookie="lbPlusSidebar=closed; path=/";
      document.getElementById('lb-plus-toggle-sidebar').classList.remove('active');
    },
    getSideBar: () => {
      return document.getElementById('lb_plus-left-sidebar');
    },
  };


  /**
   * Choose block tabs.
   *
   * @type {{attach: Drupal.behaviors.LBPlusChooseBlockTabs.attach}}
   */
  Drupal.behaviors.LBPlusChooseBlockTabs = {
    attach: (context, settings) => {
      once('LBPlusChooseBlockTabs', '.choose-block-tab', context).forEach(tab => {
        tab.onclick = (e) => {
          // Make no tab active.
          let noLongerActiveElements = [
            ...document.querySelectorAll('.tabbed-content'),
            ...document.querySelectorAll('.choose-block-tab'),
          ];
          noLongerActiveElements.forEach(tabbedContent => {
            tabbedContent.classList.remove('active');
          });
          // Activate the selected tab.
          e.target.classList.add('active')
          document.getElementById(e.target.id + '-content').classList.add('active');
        };
      });
    }
  };

  let layoutBuilderBlocksFiltered = false;

  /**
   * Provides the ability to filter the block listing in "Add block" dialog.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attach block filtering behavior to "Add block" dialog.
   */
  Drupal.behaviors.LBPlusBlockFilter = {
    attach(context) {
      const $categories = $('.js-layout-builder-categories', context);
      const $filterLinks = $categories.find('.js-layout-builder-block-link');

      /**
       * Filters the block list.
       *
       * @param {jQuery.Event} e
       *   The jQuery event for the keyup event that triggered the filter.
       */
      const filterBlockList = (e) => {
        const query = e.target.value.toLowerCase();

        /**
         * Shows or hides the block entry based on the query.
         *
         * @param {number} index
         *   The index in the loop, as provided by `jQuery.each`
         * @param {HTMLElement} link
         *   The link to add the block.
         */
        const toggleBlockEntry = (index, link) => {
          const $link = $(link);
          const textMatch =
            link.textContent.toLowerCase().indexOf(query) !== -1;
          // Checks if a category is currently hidden.
          // Toggles the category on if so.
          if ($link.closest('.js-layout-builder-category').is(':hidden')) {
            $link.closest('.js-layout-builder-category').show();
          }
          // Toggle the li tag of the matching link.
          // $link.parent().toggle(textMatch);
          $link.toggle(textMatch);
        };

        // Filter if the length of the query is at least 2 characters.
        if (query.length >= 2) {
          // Attribute to note which categories are closed before opening all.
          $categories
            .find('.js-layout-builder-category:not([open])')
            .attr('remember-closed', '');

          // Open all categories so every block is available to filtering.
          $categories.find('.js-layout-builder-category').attr('open', '');
          // Toggle visibility of links based on query.
          $filterLinks.each(toggleBlockEntry);

          // Only display categories containing visible links.
          $categories
            .find(
              '.js-layout-builder-category:not(:has(.js-layout-builder-block-link:visible))',
            )
            .hide();

          Drupal.announce(
            Drupal.formatPlural(
              $categories.find('.js-layout-builder-block-link:visible').length,
              '1 block is available in the modified list.',
              '@count blocks are available in the modified list.',
            ),
          );
          layoutBuilderBlocksFiltered = true;
        } else if (layoutBuilderBlocksFiltered) {
          layoutBuilderBlocksFiltered = false;
          // Remove "open" attr from categories that were closed pre-filtering.
          $categories
            .find('.js-layout-builder-category[remember-closed]')
            .removeAttr('open')
            .removeAttr('remember-closed');
          // Show all categories since filter is turned off.
          $categories.find('.js-layout-builder-category').show();
          // Show all blocks since filter is turned off.
          $filterLinks.show();
          Drupal.announce(Drupal.t('All available blocks are listed.'));
        }
      };

      $(
        once('block-filter-text', 'input.js-layout-builder-filter', context),
      ).on('input', Drupal.debounce(filterBlockList, 200));
    },
  };
})(jQuery, Drupal, once, Drupal.displace);
